# near-api-py

*Status: super rough, APIs are subject to change*

A Python library for development of applications that are using NEAR platform.

# Contribution

First, install the package in development mode:
```bash
python setup.py develop
```

To run tests, use nose (`pip install nose`):
```bash
nosetests
```

# License

This repository is distributed under the terms of both the MIT license and the Apache License (Version 2.0). See LICENSE and LICENSE-APACHE for details.
